gendercoder_app: Launch the gendercoder Shiny app

View source: R/gendercoder_app.R

gendercoder_appR Documentation

Launch the gendercoder Shiny app

Description

Code data interactively in a Shiny app that runs locally in RStudio or a web browser using a bs4Dash interface. The app supports CSV, Stata, SPSS, RDS, and R data files. Stata and SPSS files require the optional haven package.

Usage

gendercoder_app(...)

Arguments

...

arguments to pass to shiny::runApp()

Value

Called for its side effect of launching a Shiny app.

Examples

if (interactive()) {
gendercoder_app()
}

gendercoder documentation built on May 19, 2026, 1:08 a.m.