View source: R/gendercoder_app.R
| gendercoder_app | R Documentation |
Code data interactively in a Shiny app that runs locally in RStudio or a web browser using a bs4Dash interface. The app supports CSV, Stata, SPSS, RDS, and R data files. Stata and SPSS files require the optional haven package.
gendercoder_app(...)
... |
arguments to pass to |
Called for its side effect of launching a Shiny app.
if (interactive()) {
gendercoder_app()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.